@@ -236,6 +236,21 @@ class CaseHandler(object):
 
         return order
 
+    def _update_case_id_query(self, query, id_list):
+        """Update a case query ["_id"]["$in"] values using an additional list of case _ids
+
+        Args:
+            query(dict): a query dictionary that contains a ["_id"]["$in"] key with case _ids as value
+            id_list(list): a list of case _ids to update query with
+        """
+        if query.get("_id"):  # Check if other filter already limits the search by case _id
+            preselected_ids = query["_id"].get("$in", [])
+            query["_id"]["$in"] = list(
+                set(preselected_ids).intersection(set(id_list))
+            )  # limit also by case _ids present in id_list
+        else:  # use id_list for filtering
+            query["_id"] = {"$in": id_list}
+
     def cases(
         self,
         owner=None,
@@ -248,6 +263,7 @@ class CaseHandler(object):
         finished=False,
         research_requested=False,
         is_research=False,
+        has_rna_data=False,
         status=None,
         phenotype_terms=False,
         group=None,
@@ -258,6 +274,7 @@ class CaseHandler(object):
         within_days=None,
         assignee=None,
         verification_pending=None,
+        has_clinvar_submission=None,
     ):
         """Fetches all cases from the backend.
 
@@ -271,7 +288,8 @@ class CaseHandler(object):
             finished(bool)
             research_requested(bool)
             is_research(bool)
-            status(str)
+            has_rna_data(bool): if case has RNA-seq data associated
+            status(str or dict expression)
             group(ObjectId): fetch all cases in a named case group
             cohort(bool): Fetch all cases with cohort tags
             phenotype_terms(bool): Fetch all cases with phenotype
@@ -283,6 +301,7 @@ class CaseHandler(object):
             within_days(int): timespan (in days) for latest event on case
             assignee(str): email of an assignee
             verification_pending(bool): If search should be restricted to cases with verification_pending
+            has_clinvar_submission(bool): If search should be limited to cases with a ClinVar submission
 
         Returns:
             Cases ordered by date.
@@ -290,56 +309,102 @@ class CaseHandler(object):
                 instead returns corresponding query dict
                 that can be reused in compound queries or for testing.
         """
+
+        def _conditional_set_query_value(query, condition, set_key, set_value):
+            """Adds kes/values to a growing query dictionary for selecting cases from db.
+            Checks if 'condition' has a value. If it does, adds set_key/set_value as key/value to the growing
+            query dictionary
+
+            Args:
+                query(dict): case query dictionary
+                condition(misc): a variable that could have a value or be None
+                set_key(str): new query key query[set_key]
+                set_value(misc): value to assign to query[set_key]
+            """
+            if condition:
+                query[set_key] = set_value
+
         query = query or {}
         order = None
         # Prioritize when both owner and collaborator params are present
         if collaborator and owner:
             collaborator = None
 
-        if collaborator:
-            query["collaborators"] = collaborator
+        _conditional_set_query_value(
+            query=query, condition=collaborator, set_key="collaborators", set_value=collaborator
+        )
 
-        if owner:
-            query["owner"] = owner
+        _conditional_set_query_value(query=query, condition=owner, set_key="owner", set_value=owner)
 
-        if skip_assigned:
-            query["assignees"] = {"$exists": False}
+        _conditional_set_query_value(
+            query=query, condition=skip_assigned, set_key="assignees", set_value={"$exists": False}
+        )
 
-        if has_causatives:
-            query["causatives"] = {"$exists": True, "$ne": []}
+        _conditional_set_query_value(
+            query=query,
+            condition=has_causatives,
+            set_key="causatives",
+            set_value={"$exists": True, "$ne": []},
+        )
 
-        if reruns:
-            query["rerun_requested"] = True
+        _conditional_set_query_value(
+            query=query, condition=reruns, set_key="rerun_requested", set_value=True
+        )
 
-        if rerun_monitor:
-            query["rerun_monitoring"] = True
+        _conditional_set_query_value(
+            query=query, condition=rerun_monitor, set_key="rerun_monitoring", set_value=True
+        )
 
-        if status:
-            query["status"] = status
+        _conditional_set_query_value(
+            query=query, condition=status, set_key="status", set_value=status
+        )
 
-        elif finished:
-            query["status"] = {"$in": ["solved", "archived"]}
+        _conditional_set_query_value(
+            query=query,
+            condition=finished,
+            set_key="status",
+            set_value={"$in": ["solved", "archived"]},
+        )
 
-        if research_requested:
-            query["research_requested"] = True
+        _conditional_set_query_value(
+            query=query, condition=research_requested, set_key="research_requested", set_value=True
+        )
 
-        if is_research:
-            query["is_research"] = {"$exists": True, "$eq": True}
+        _conditional_set_query_value(
+            query=query,
+            condition=is_research,
+            set_key="is_research",
+            set_value={"$exists": True, "$eq": True},
+        )
 
-        if phenotype_terms:
-            query["phenotype_terms"] = {"$exists": True, "$ne": []}
+        _conditional_set_query_value(
+            query=query,
+            condition=phenotype_terms,
+            set_key="phenotype_terms",
+            set_value={"$exists": True, "$ne": []},
+        )
 
-        if pinned:
-            query["suspects"] = {"$exists": True, "$ne": []}
+        _conditional_set_query_value(
+            query=query,
+            condition=pinned,
+            set_key="suspects",
+            set_value={"$exists": True, "$ne": []},
+        )
 
-        if cohort:
-            query["cohorts"] = {"$exists": True, "$ne": []}
+        _conditional_set_query_value(
+            query=query,
+            condition=cohort,
+            set_key="cohorts",
+            set_value={"$exists": True, "$ne": []},
+        )
 
-        if group:
-            query["group"] = {"$in": [group]}
+        _conditional_set_query_value(
+            query=query, condition=group, set_key="group", set_value={"$in": [group]}
+        )
 
-        if assignee:
-            query["assignees"] = {"$in": [assignee]}
+        _conditional_set_query_value(
+            query=query, condition=assignee, set_key="assignees", set_value={"$in": [assignee]}
+        )
 
         if name_query:
             # Case search filter form query
@@ -354,13 +419,15 @@ class CaseHandler(object):
 
         if verification_pending:  # Filter for cases with Sanger verification pending
             sanger_pending_cases = self.verification_missing_cases(owner)
-            if query.get("_id"):  # Check if other filter already limits the search by case _id
-                preselected_ids = query["_id"].get("$in", [])
-                query["_id"]["$in"] = list(
-                    set(preselected_ids).intersection(set(sanger_pending_cases))
-                )  # limit also by Sanger pending
-            else:  # Apply only Sanger pending filter
-                query["_id"] = {"$in": sanger_pending_cases}
+            self._update_case_id_query(query, sanger_pending_cases)
+
+        if has_clinvar_submission:
+            clinvar_subm_cases = self.clinvar_cases(collaborator or owner)
+            self._update_case_id_query(query, clinvar_subm_cases)
+
+        if has_rna_data:
+            cases_with_rna = self.rna_cases(collaborator or owner)
+            self._update_case_id_query(query, cases_with_rna)
 
         if yield_query:
             return query
@@ -370,6 +437,27 @@ class CaseHandler(object):
 
         return self.case_collection.find(query).sort("updated_at", -1)
 
+    def rna_cases(self, owner):
+        """Retrieve all cases with RNA-seq data for a given institute
+
+        Args:
+            owner(str): _id of an institute
+
+        Returns:
+            list of case _ids
+        """
+        EXISTS_NOT_NULL = {"$exists": True, "$nin": [None, ""]}
+        query = {
+            "owner": owner,
+            "$or": [
+                {"gene_fusion_report": EXISTS_NOT_NULL},
+                {"gene_fusion_report_research": EXISTS_NOT_NULL},
+                {"individuals.splice_junctions_bed": EXISTS_NOT_NULL},
+                {"individuals.rna_coverage_bigwig": EXISTS_NOT_NULL},
+            ],
+        }
+        return [case["_id"] for case in self.case_collection.find(query)]
+
     def last_modified_cases(
         self, within_days, has_causatives, finished, reruns, research_requested, status
     ):
@@ -475,10 +563,9 @@ class CaseHandler(object):
     def nr_cases(self, institute_id=None):
         """Return the number of cases
 
-        This function will change when we migrate to 3.7.1
 
         Args:
-            collaborator(str): Institute id
+            institute_id(str): Institute id
 
         Returns:
             nr_cases(int)
@@ -492,6 +579,21 @@ class CaseHandler(object):
 
         return nr_cases
 
+    def nr_cases_by_status(self, institute_id=None):
+        """For an institute, retrieves number of cases in each case status category
+        Args:
+            institute_id(str): Institute id
+
+        Returns:
+            dict with case.status as keys and nr cases as value
+        """
+        pipeline = []
+        if institute_id:
+            pipeline.append({"$match": {"collaborators": institute_id}})
+        pipeline.append({"$group": {"_id": "$status", "count": {"$sum": 1}}})
+        result = self.case_collection.aggregate(pipeline)
+        return {res["_id"]: res["count"] for res in result}
+
     def update_dynamic_gene_list(
         self,
         case,
@@ -827,6 +929,7 @@ class CaseHandler(object):
             - collaborators: If new collaborators these will be added to the old ones
             - coverage_qc_report: path to the static coverage and qc report file
             - delivery_report: path to the static delivery report file
+            - exe_ver: path to the pipeline executable version report file
             - gene_fusion_report: path to the gene fusions report
             - gene_fusion_report_research: path to the research gene fusions report
             - genome_build: If there is a new genome build
@@ -839,6 +942,7 @@ class CaseHandler(object):
             - multiqc: If there's an updated multiqc report location
             - panels: The new gene panels are added
             - rank_model_version: If there is a new rank model
+            - reference_info: path to the pipeline reference version report file
             - rerun_requested: Is set to False since that is probably what happened
             - research_requested: Boolean, if research variants where requested for this case
             - smn_tsv: path to static SMN TSV file
@@ -886,6 +990,7 @@ class CaseHandler(object):
                 "cnv_report": case_obj.get("cnv_report"),
                 "coverage_qc_report": case_obj.get("coverage_qc_report"),
                 "delivery_report": case_obj.get("delivery_report"),
+                "exe_ver": case_obj.get("exe_ver"),
                 "gene_fusion_report": case_obj.get("gene_fusion_report"),
                 "gene_fusion_report_research": case_obj.get("gene_fusion_report_research"),
                 "genome_build": case_obj.get("genome_build", "37"),
@@ -896,10 +1001,12 @@ class CaseHandler(object):
                 "madeline_info": case_obj.get("madeline_info"),
                 "mme_submission": case_obj.get("mme_submission"),
                 "multiqc": case_obj.get("multiqc"),
+                "multiqc_rna": case_obj.get("multiqc_rna"),
                 "panels": case_obj.get("panels", []),
                 "rank_model_version": case_obj.get("rank_model_version"),
                 "rerun_requested": case_obj.get("rerun_requested", False),
                 "research_requested": case_obj.get("research_requested", False),
+                "reference_info": case_obj.get("reference_info"),
                 "smn_tsv": case_obj.get("smn_tsv"),
                 "status": case_obj.get("status"),
                 "sv_rank_model_version": case_obj.get("sv_rank_model_version"),
@@ -926,12 +1033,15 @@ class CaseHandler(object):
         for key in [
             "custom_images",
             "cnv_report",
+            "exe_ver",
             "coverage_qc_report",
             "gene_fusion_report",
             "gene_fusion_report_research",
             "mme_submission",
             "multiqc",
+            "multiqc_rna",
             "rank_model_version",
+            "reference_info",
             "smn_tsv",
             "sv_rank_model_version",
         ]:
