@@ -131,7 +131,7 @@ class ClinVarHandler(object):
 
         Args:
             submission_id(str) : id of the submission to be updated
-            submission_objects(tuple): a tuple of 2 elements coresponding to a list of variants and a list of case data objects to add to submission
+            submission_objects(tuple): a tuple of 2 elements of this type: (scout.models.clinvar.clinvar_variant, [scout.models.clinvar.clinvar_casedata1, ..] )
 
         Returns:
             updated_submission(obj): an open clinvar submission object, updated
@@ -144,23 +144,23 @@ class ClinVarHandler(object):
 
         # Insert variant submission_objects into clinvar collection
         # Loop over the objects
-        for var_obj in submission_objects[0]:
-            try:
-                result = self.clinvar_collection.insert_one(var_obj)
-                self.clinvar_submission_collection.update_one(
-                    {"_id": submission_id},
-                    {"$push": {"variant_data": str(result.inserted_id)}},
-                    upsert=True,
-                )
-            except pymongo.errors.DuplicateKeyError:
-                LOG.error("Attepted to insert a clinvar variant which is already in DB!")
+        var_dict = submission_objects[0]
+        try:
+            result = self.clinvar_collection.insert_one(var_dict)
+            self.clinvar_submission_collection.update_one(
+                {"_id": submission_id},
+                {"$push": {"variant_data": str(result.inserted_id)}},
+                upsert=True,
+            )
+        except pymongo.errors.DuplicateKeyError:
+            LOG.error("Attepted to insert a clinvar variant which is already in DB!")
 
         # Insert casedata submission_objects into clinvar collection
         if submission_objects[1]:
             # Loop over the objects
-            for case_obj in submission_objects[1]:
+            for casedata_obj in submission_objects[1]:
                 try:
-                    result = self.clinvar_collection.insert_one(case_obj)
+                    result = self.clinvar_collection.insert_one(casedata_obj)
                     self.clinvar_submission_collection.update_one(
                         {"_id": submission_id},
                         {"$push": {"case_data": str(result.inserted_id)}},
@@ -182,20 +182,17 @@ class ClinVarHandler(object):
         """Set a clinvar submission ID to 'closed'
 
         Args:
-            submission_id(str): the ID of the clinvar submission to close
+            submission_id(str): the ID of the clinvar submission to updte status for
 
         Return
             updated_submission(obj): the submission object with a 'closed' status
 
         """
-        LOG.info('closing clinvar submission "%s"', submission_id)
-
-        if (
-            status == "open"
-        ):  # just close the submission its status does not affect the other submissions
-            # Close all other submissions for this institute and then open the desired one
+        # When setting one submission as open
+        # Close all other submissions for this institute first
+        if status == "open":
             self.clinvar_submission_collection.update_many(
-                {"institute_id": institute_id},
+                {"institute_id": institute_id, "status": "open"},
                 {"$set": {"status": "closed", "updated_at": datetime.now()}},
             )
         updated_submission = self.clinvar_submission_collection.find_one_and_update(
@@ -288,6 +285,25 @@ class ClinVarHandler(object):
 
         return submissions
 
+    def clinvar_assertion_criteria(self, variant_data):
+        """Retrieve assertion criteria from the variant data of a submission.
+           ClinVar no longer supports Assertion Criteria data as columns of the CSV file,
+           so it has to be passed as optional parameters the the ClinVar API helper (preClinVar)
+
+        Args:
+            variant_data(dict): a document from the store.clinvar collection
+
+        Returns:
+            criteria (dict): a dict containing assertionCriteriaDB and assertionCriteriaID key/values
+                             or None
+        """
+        amc = variant_data.get("assertion_method_cit", "")
+        if ":" in amc:
+            amc_db = amc.split(":")[0].replace("PMID", "PubMed")
+            amc_id = amc.split(":")[1]
+            criteria = {"assertionCriteriaDB": amc_db, "assertionCriteriaID": amc_id}
+            return criteria
+
     def clinvar_objs(self, submission_id, key_id):
         """Collects a list of objects from the clinvar collection (variants of case data) as specified by the key_id in the clinvar submission
 
@@ -353,9 +369,6 @@ class ClinVarHandler(object):
         Returns:
             updated_submission(obj): an updated clinvar submission
         """
-
-        LOG.info("Deleting clinvar object %s (%s)", object_id, object_type)
-
         # If it's a variant object to be removed:
         #   remove reference to it in the submission object 'variant_data' list field
         #   remove the variant object from clinvar collection
@@ -416,3 +429,18 @@ class ClinVarHandler(object):
             submitted_vars[clinvar.get("local_id")] = clinvar
 
         return submitted_vars
+
+    def clinvar_cases(self, institute_id=None):
+        """Fetch all cases with variants contained in a ClinVar submission object
+
+        Args:
+            institute_id(str): id of an institute
+        Returns:
+            clinvar_case_ids(list): list of case _ids
+        """
+        clinvar_case_ids = set()
+        inst_submissions = self.clinvar_submissions(institute_id=institute_id)
+        for subm in inst_submissions:
+            for var in subm.get("variant_data"):
+                clinvar_case_ids.add(var["case_id"])
+        return list(clinvar_case_ids)
