@@ -11,10 +11,12 @@ from cyvcf2 import VCF
 
 # Local modules
 from scout.utils.coordinates import is_par
+from scout.utils.md5 import generate_md5_key
 
 from .variant_loader import VariantLoader
 
 LOG = logging.getLogger(__name__)
+MATCHQ = "$match"
 
 
 class VariantHandler(VariantLoader):
@@ -334,98 +336,17 @@ class VariantHandler(VariantLoader):
             if hit["length"] == closest_length:
                 return hit
 
-    def gene_variants(
-        self,
-        query=None,
-        category="snv",
-        variant_type=["clinical"],
-        institute_id=None,
-        nr_of_variants=50,
-        skip=0,
-    ):
-        """Return all variants seen in a given gene.
-
-        If skip not equal to 0 skip the first n variants.
-
-        Args:
-            query(dict): A dictionary with querys for the database, including
-            variant_type: 'clinical', 'research'
-            category(str): 'sv', 'str', 'snv', 'cancer' or 'cancer_sv'
-            institute_id: institute ID (required for similarity query)
-            nr_of_variants(int): if -1 return all variants
-            skip(int): How many variants to skip
-
-        Query can contain:
-            phenotype_terms,
-            phenotype_groups,
-            similar_case,
-            cohorts
-        """
-        mongo_variant_query = self.build_variant_query(
-            query=query,
-            institute_id=institute_id,
-            category=category,
-            variant_type=variant_type,
-        )
-
-        sorting = [("rank_score", pymongo.DESCENDING)]
-
-        if nr_of_variants == -1:
-            nr_of_variants = 0  # This will return all variants
-        else:
-            nr_of_variants = skip + nr_of_variants
-
-        result = (
-            self.variant_collection.find(mongo_variant_query)
-            .sort(sorting)
-            .skip(skip)
-            .limit(nr_of_variants)
-        )
-
-        return result
-
-    def count_gene_variants(
-        self, query=None, category="snv", variant_type=["clinical"], institute_id=None
-    ):
-        """Count all variants seen in a given gene.
-
-        Args:
-            query(dict): A dictionary with querys for the database, including
-            variant_type: 'clinical', 'research'
-            category(str): 'sv', 'str', 'snv', 'cancer' or 'cancer_sv'
-            institute_id: institute ID (required for similarity query)
-
-        Query can contain:
-            phenotype_terms,
-            phenotype_groups,
-            similar_case,
-            cohorts
-
-        Returns:
-            Number of variants for gene
-        """
-        mongo_variant_query = self.build_variant_query(
-            query=query,
-            institute_id=institute_id,
-            category=category,
-            variant_type=variant_type,
-        )
-
-        return self.variant_collection.count_documents(mongo_variant_query)
-
-    def verified(self, institute_id):
-        """Return all verified variants for a given institute
+    def validations_ordered(self, institute_id):
+        """Return all unique variant validations ordered for a given institute (events collection)
 
         Args:
             institute_id(str): institute id
 
         Returns:
-            res(list): a list with validated variants
+            pymongo.cursor
         """
-        res = []
-
         # Build the query pipeline
-        query = {"$match": {"verb": "validate", "institute": institute_id}}
+        query = {MATCHQ: {"verb": "validate", "institute": institute_id, "category": "variant"}}
         group = {
             "$group": {
                 "_id": {
@@ -434,8 +355,20 @@ class VariantHandler(VariantLoader):
                 },
             }
         }
+        sort = {"$sort": {"_id.case": 1}}  # Sort by case _id
+        return self.event_collection.aggregate([query, group, sort])
 
-        validate_events = self.event_collection.aggregate([query, group])
+    def verified(self, institute_id):
+        """Return all verified (True Positive or False positive) variants for a given institute, sorted by case _id
+
+        Args:
+            institute_id(str): institute id
+
+        Returns:
+            res(list): a list with validated variants
+        """
+        res = []
+        validate_events = self.validations_ordered(institute_id)
         for event in validate_events:
             case_id = event["_id"]["case"]
             variant_id = event["_id"]["variant_id"]
@@ -449,6 +382,8 @@ class VariantHandler(VariantLoader):
             var_obj["case_obj"] = {
                 "display_name": case_obj["display_name"],
                 "individuals": case_obj["individuals"],
+                "status": case_obj["status"],
+                "partial_causatives": case_obj.get("partial_causatives", []),
             }
             res.append(var_obj)
 
@@ -477,7 +412,7 @@ class VariantHandler(VariantLoader):
             query = self.case_collection.aggregate(
                 [
                     {
-                        "$match": {
+                        MATCHQ: {
                             "collaborators": institute_id,
                             "causatives": {"$exists": True},
                         }
@@ -541,7 +476,7 @@ class VariantHandler(VariantLoader):
         Args:
             case_obj (dict): A Case object.
             institute_obj (dict): An Institute object.
-            positional_variant_ids (iterable): A set of possible positional variant ids to look for
+            positional_variant_ids (iterable): A set of possible variant_ids (md5 key based upon a list like this: [ "17", "7577559", "G" "A", "research"]
             limit_genes (list): list of gene hgnc_ids to limit the search to
 
         Returns:
@@ -605,13 +540,20 @@ class VariantHandler(VariantLoader):
                 continue
             other_link = var_event["link"]
             # link contains other variant ID
-            other_causative_id = other_link.split("/")[-1]
+            other_causative_id = other_link.split("/")[-1]  # md5-key _id of a variant
 
-            if other_causative_id in other_case.get("causatives", []):
-                positional_variant_ids.add(var_event["variant_id"])
+            if (
+                other_causative_id not in other_case.get("causatives", [])
+                and other_causative_id not in other_case.get("partial_causatives", {}).keys()
+            ):
+                continue
 
-            if other_causative_id in other_case.get("partial_causatives", {}).keys():
-                positional_variant_ids.add(var_event["variant_id"])
+            other_var_simple = var_event.get("subject").split("_")[
+                0:4
+            ]  # example: [ "17", "7577559", "G" "A"]
+
+            for variant_type in ["clinical", "reseach"]:
+                positional_variant_ids.add(generate_md5_key(other_var_simple + [variant_type]))
 
         return self.match_affected_gt(case_obj, institute_obj, positional_variant_ids, limit_genes)
 
@@ -973,7 +915,7 @@ class VariantHandler(VariantLoader):
             return case_obj["variants_stats"]
 
         # Update case variant stats
-        match = {"$match": {"case_id": case_id, "institute": institute_id}}
+        match = {MATCHQ: {"case_id": case_id, "institute": institute_id}}
         group = {
             "$group": {
                 "_id": {"type": "$variant_type", "category": "$category"},
