@@ -1,12 +1,21 @@
 ANALYSIS_TYPES = ("wgs", "wes", "mixed", "unknown", "panel", "panel-umi", "external")
 
-CUSTOM_CASE_REPORTS = [
-    "multiqc",
-    "cnv_report",
-    "coverage_qc_report",
-    "gene_fusion_report",
-    "gene_fusion_report_research",
-]
+# keys are used in the load report cli, while key_name is saved in case database documents
+CUSTOM_CASE_REPORTS = {
+    "delivery": {"key_name": "delivery_report", "format": "HTML", "pdf_export": True},
+    "cnv": {"key_name": "cnv_report", "format": "PDF", "pdf_export": False},
+    "cov_qc": {"key_name": "coverage_qc_report", "format": "HTML", "pdf_export": True},
+    "exe_ver": {"key_name": "pipeline_version", "format": "YAML", "pdf_export": True},
+    "multiqc": {"key_name": "multiqc", "format": "HTML", "pdf_export": False},
+    "multiqc_rna": {"key_name": "multiqc_rna", "format": "HTML", "pdf_export": False},
+    "gene_fusion": {"key_name": "gene_fusion_report", "format": "PDF", "pdf_export": False},
+    "gene_fusion_research": {
+        "key_name": "gene_fusion_report_research",
+        "format": "PDF",
+        "pdf_export": False,
+    },
+    "reference_info": {"key_name": "reference_info", "format": "YAML", "pdf_export": True},
+}
 
 CASE_REPORT_CASE_FEATURES = [
     "display_name",
@@ -57,7 +66,7 @@ PHENOTYPE_MAP = {1: "unaffected", 2: "affected", 0: "unknown", -9: "unknown"}
 CANCER_PHENOTYPE_MAP = {1: "normal", 2: "tumor", 0: "unknown", -9: "unknown"}
 REV_PHENOTYPE_MAP = {value: key for key, value in PHENOTYPE_MAP.items()}
 
-CASE_STATUSES = ("prioritized", "inactive", "active", "solved", "archived")
+CASE_STATUSES = ("prioritized", "inactive", "active", "solved", "archived", "ignored")
 
 VERBS_MAP = {
     "assign": "was assigned to",
