@@ -8,10 +8,13 @@ EXPORT_HEADER = [
     "Gene_name",
     "Canonical_transcript/HGVS/protein_change",
     "Primary_transcript/HGVS/protein_change",
+    "Consequence",
     "CADD",
     "GnomAD AF",
 ]
 
+CANCER_EXPORT_HEADER = EXPORT_HEADER + ["VAF TUMOR", "VAF NORMAL", "COSMIC ID"]
+
 MT_EXPORT_HEADER = [
     "Position",
     "Change",
@@ -28,6 +31,12 @@ MT_COV_STATS_HEADER = [
     "Estimated mtDNA copy number",
 ]
 
+MITODEL_HEADER = [
+    "Normal MT read pair count",
+    "Discordant MT read pair count",
+    "MT discordant ratio (ppk)",
+]
+
 VCF_HEADER = [
     "##fileformat=VCFv4.2",
     '##INFO=<ID=END,Number=1,Type=Integer,Description="End position of the variant described in this record">',
