@@ -16,6 +16,7 @@ from .blueprints import (
     alignviewers,
     api,
     cases,
+    clinvar,
     dashboard,
     diagnoses,
     genes,
@@ -163,12 +164,17 @@ def configure_extensions(app):
         LOG.info("Collecting IGV tracks from cloud resources")
         extensions.cloud_tracks.init_app(app)
 
+    if app.config.get("PHENOPACKET_API_URL"):
+        LOG.info("Enable Phenopacket API")
+        extensions.phenopacketapi.init_app(app)
+
 
 def register_blueprints(app):
     """Register Flask blueprints."""
     app.register_blueprint(public.public_bp)
     app.register_blueprint(genes.genes_bp)
     app.register_blueprint(cases.cases_bp)
+    app.register_blueprint(clinvar.clinvar_bp)
     app.register_blueprint(login.login_bp)
     app.register_blueprint(variant.variant_bp)
     app.register_blueprint(variants.variants_bp)
@@ -210,6 +216,12 @@ def register_filters(app):
         # round all other numbers
         return round(number, ndigits)
 
+    @app.template_filter()
+    def tuple_list_to_dict(tuple_list, key_elem, value_elem):
+        """Accepts a list of tuples and returns a dictionary with tuple element = key_elem as keys and tuple element = value_elem as values"""
+
+        return {tup[key_elem]: tup[value_elem] for tup in tuple_list}
+
     @app.template_filter()
     def url_decode(string):
         """Decode a string with encoded hex values."""
