@@ -10,7 +10,6 @@ from flask_login import current_user
 from pymongo import ASCENDING, DESCENDING
 
 from scout.constants import CASE_SEARCH_TERMS, CASE_STATUSES, PHENOTYPE_GROUPS
-from scout.parse.clinvar import clinvar_submission_header, clinvar_submission_lines
 from scout.server.blueprints.variant.utils import predictions, update_representative_gene
 from scout.server.extensions import beacon, store
 from scout.server.utils import institute_and_case, user_institutes
@@ -328,6 +327,10 @@ def update_institute_settings(store, institute_obj, form):
     for cohort in form.getlist("cohorts"):
         cohorts.append(cohort.strip())
 
+    loqusdb_ids = form.getlist("loqusdb_id")
+    if current_user.is_admin is False:
+        loqusdb_ids = None
+
     updated_institute = store.update_institute(
         internal_id=institute_obj["_id"],
         sanger_recipients=sanger_recipients,
@@ -341,7 +344,7 @@ def update_institute_settings(store, institute_obj, form):
         add_groups=False,
         sharing_institutes=sharing_institutes,
         cohorts=cohorts,
-        loqusdb_ids=form.getlist("loqusdb_id"),
+        loqusdb_ids=loqusdb_ids,
         alamut_key=form.get("alamut_key"),
         check_show_all_vars=form.get("check_show_all_vars"),
     )
@@ -410,11 +413,14 @@ def cases(store, request, institute_id):
         name_query=name_query,
         skip_assigned=request.args.get("skip_assigned"),
         is_research=request.args.get("is_research"),
+        has_rna_data=request.args.get("has_rna"),
         verification_pending=request.args.get("validation_ordered"),
+        has_clinvar_submission=request.args.get("clinvar_submitted"),
     )
     all_cases = _sort_cases(data, request, all_cases)
 
     data["nr_cases"] = store.nr_cases(institute_id=institute_id)
+    data["status_ncases"] = store.nr_cases_by_status(institute_id=institute_id)
     data["sanger_unevaluated"] = get_sanger_unevaluated(store, institute_id, current_user.email)
 
     case_groups = {status: [] for status in CASE_STATUSES}
@@ -579,134 +585,6 @@ def filters(store, institute_id):
     return filters
 
 
-def clinvar_submissions(store, institute_id):
-    """Get all Clinvar submissions for a user and an institute"""
-    submissions = list(store.clinvar_submissions(institute_id))
-    return submissions
-
-
-def update_clinvar_submission_status(store, request_obj, institute_id, submission_id):
-    """Update the status of a clinVar submission
-
-    Args:
-        store(adapter.MongoAdapter)
-        request_obj(flask.request) POST request sent by form submission
-        institute_id(str) institute id
-        submission_id(str) the database id of a clinvar submission
-    """
-    update_status = request_obj.form.get("update_submission")
-
-    if update_status in ["open", "closed"]:  # open or close a submission
-        store.update_clinvar_submission_status(institute_id, submission_id, update_status)
-    if update_status == "register_id":  # register an official clinvar submission ID
-        result = store.update_clinvar_id(
-            clinvar_id=request_obj.form.get("clinvar_id"),
-            submission_id=submission_id,
-        )
-    if update_status == "delete":  # delete a submission
-        deleted_objects, deleted_submissions = store.delete_submission(submission_id=submission_id)
-        flash(
-            f"Removed {deleted_objects} objects and {deleted_submissions} submission from database",
-            "info",
-        )
-
-
-def update_clinvar_sample_names(store, submission_id, case_id, old_name, new_name):
-    """Update casedata sample names
-
-    Args:
-        store(adapter.MongoAdapter)
-        submission_id(str) the database id of a clinvar submission
-        case_id(str): case id
-        old_name(str): old name of an individual in case data
-        new_name(str): new name of an individual in case data
-    """
-    n_renamed = store.rename_casedata_samples(submission_id, case_id, old_name, new_name)
-    flash(
-        f"Renamed {n_renamed} case data individuals from '{old_name}' to '{new_name}'",
-        "info",
-    )
-
-
-def clinvar_submission_file(store, submission_id, csv_type, clinvar_subm_id):
-    """Prepare content (header and lines) of a csv clinvar submission file
-
-    Args:
-        store(adapter.MongoAdapter)
-        submission_id(str): the database id of a clinvar submission
-        csv_type(str): 'variant_data' or 'case_data'
-        clinvar_subm_id(str): The ID assigned to this submission by clinVar
-
-    Returns:
-        (filename, csv_header, csv_lines):
-            filename(str) name of file to be downloaded
-            csv_header(list) string list content of file header
-            csv_lines(list) string list content of file lines
-    """
-    if clinvar_subm_id == "None":
-        flash(
-            "In order to download a submission CSV file you should register a Clinvar submission Name first!",
-            "warning",
-        )
-        return
-
-    submission_objs = store.clinvar_objs(submission_id=submission_id, key_id=csv_type)
-
-    if submission_objs is None or len(submission_objs) == 0:
-        flash(
-            f"There are no submission objects of type '{csv_type}' to include in the csv file!",
-            "warning",
-        )
-        return
-
-    # Download file
-    csv_header_obj = clinvar_header(submission_objs, csv_type)
-    csv_lines = clinvar_lines(submission_objs, csv_header_obj)
-    csv_header = list(csv_header_obj.values())
-    csv_header = [
-        '"' + str(x) + '"' for x in csv_header
-    ]  # quote columns in header for csv rendering
-
-    today = str(datetime.datetime.now().strftime("%Y-%m-%d"))
-    if csv_type == "variant_data":
-        filename = f"{clinvar_subm_id}_{today}.Variant.csv"
-    else:
-        filename = f"{clinvar_subm_id}_{today}.CaseData.csv"
-
-    return (filename, csv_header, csv_lines)
-
-
-def clinvar_header(submission_objs, csv_type):
-    """Call clinvar parser to extract required fields to include in csv header from clinvar submission objects
-
-    Args:
-        submission_objs(list)
-        csv_type(str)
-
-    Returns:
-        clinvar_header_obj(dict) # custom csv header (dict based on constants CLINVAR_HEADER and CASEDATA_HEADER, but with required fields only)
-    """
-
-    clinvar_header_obj = clinvar_submission_header(submission_objs, csv_type)
-    return clinvar_header_obj
-
-
-def clinvar_lines(clinvar_objects, clinvar_header_obj):
-    """Call clinvar parser to extract required lines to include in csv file from clinvar submission objects and header
-
-    Args:
-        clinvar_objects(list)
-        clinvar_header_obj(dict)
-
-    Returns:
-        clinvar_lines(list) # csv lines (one for each variant/casedata to be submitted)
-
-    """
-
-    clinvar_lines = clinvar_submission_lines(clinvar_objects, clinvar_header_obj)
-    return clinvar_lines
-
-
 def update_variant_genes(store, variant_obj, genome_build):
     """Update the HGNC symbols and HGVS predictions if they are not set
 
