@@ -1,6 +1,4 @@
-import datetime
 import logging
-import os.path
 import re
 from datetime import date
 
@@ -9,12 +7,10 @@ from flask import Response, flash, url_for
 from flask_login import current_user
 from pymongo.errors import DocumentTooLarge
 from werkzeug.datastructures import Headers, MultiDict
-from xlsxwriter import Workbook
 
 from scout.constants import (
     ACMG_COMPLETE_MAP,
     ACMG_MAP,
-    CALLERS,
     CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
     CANCER_TIER_OPTIONS,
     CHROMOSOMES,
@@ -26,8 +22,7 @@ from scout.constants import (
     SPIDEX_HUMAN,
     VARIANT_FILTERS,
 )
-from scout.constants.variants_export import EXPORT_HEADER, VERIFIED_VARIANTS_HEADER
-from scout.export.variant import export_verified_variants
+from scout.constants.variants_export import CANCER_EXPORT_HEADER, EXPORT_HEADER
 from scout.server.blueprints.variant.utils import (
     clinsig_human,
     predictions,
@@ -41,19 +36,23 @@ from scout.server.utils import (
     user_institutes,
 )
 
-from .forms import (  # noqa: F401; noqa: F401
-    FILTERSFORMCLASS,
-    CancerFiltersForm,
-    CancerSvFiltersForm,
-    FiltersForm,
-    StrFiltersForm,
-    SvFiltersForm,
-    VariantFiltersForm,
-)
+from .forms import FILTERSFORMCLASS, CancerSvFiltersForm, SvFiltersForm
 
 LOG = logging.getLogger(__name__)
 
 
+def populate_force_show_unaffected_vars(institute_obj, form):
+    """Whenever a user institute contains the key/value check_show_all_vars=True,
+    then all variants (and not only those occurring in affected individuals) should be shown
+
+    Args:
+        institute_obj(dict): scout.models.institute
+        form(VariantFiltersForm)
+    """
+    if institute_obj.get("check_show_all_vars"):
+        form.show_unaffected.data = True
+
+
 def populate_chrom_choices(form, case_obj):
     """Populate the option of the chromosome select according to the case genome build"""
     # Populate chromosome choices
@@ -958,25 +957,52 @@ def variant_export_lines(store, case_obj, variants_query):
         gene_list = variant.get("genes")  # this is a list of gene objects
 
         # if variant is in genes
-        if gene_list is not None and len(gene_list) > 0:
+        if gene_list:
             gene_info = variant_export_genes_info(store, gene_list, case_obj.get("genome_build"))
             variant_line += gene_info
         else:
             empty_col = 0
-            while empty_col < 3:
+            while empty_col < 4:
                 variant_line.append(
                     "-"
-                )  # empty HGNC id, emoty gene name and empty transcripts columns
+                )  # empty HGNC id, empty gene name and empty transcripts columns
                 empty_col += 1
 
-        variant_line.append(variant.get("cadd_score", "N/A"))
+        if variant.get("cadd_score"):
+            variant_line.append(round(variant["cadd_score"], 2))
+        else:
+            variant_line.append("N/A")
 
-        variant_line.append(variant.get("gnomad_frequency", "N/A"))
+        if variant.get("gnomad_frequency"):
+            variant_line.append(round(variant["gnomad_frequency"], 5))
+        else:
+            variant_line.append("N/A")
+
+        if case_obj.get("track") == "cancer":
+            # Add cancer and normal VAFs
+            for sample in ["tumor", "normal"]:
+                allele = variant.get(sample)
+                if not allele:
+                    variant_line.append("-")
+                    continue
+                alt_freq = round(allele.get("alt_freq", 0), 4)
+                alt_depth = allele.get("alt_depth")
+                ref_depth = allele.get("ref_depth")
+
+                vaf_sample = f"{alt_freq} ({alt_depth}|{ref_depth})"
+                variant_line.append(vaf_sample)
+
+            # ADD eventual COSMIC ID
+            cosmic_ids = variant.get("cosmic_ids") or ["-"]
+            variant_line.append(" | ".join(cosmic_ids))
+
+        else:
+            variant_gts = variant["samples"]  # list of coverage and gt calls for case samples
+            for individual in case_obj["individuals"]:
+                for variant_gt in variant_gts:
+                    if individual["individual_id"] != variant_gt["sample_id"]:
+                        continue
 
-        variant_gts = variant["samples"]  # list of coverage and gt calls for case samples
-        for individual in case_obj["individuals"]:
-            for variant_gt in variant_gts:
-                if individual["individual_id"] == variant_gt["sample_id"]:
                     variant_line.append(variant_gt["genotype_call"])
                     # gather coverage info
                     variant_line.append(variant_gt["allele_depths"][0])  # AD reference
@@ -1044,6 +1070,7 @@ def variant_export_genes_info(store, gene_list, genome_build="37"):
     gene_names = []
     canonical_txs = []
     primary_txs = []
+    funct_annos = []
     gene_info = []
 
     for gene_obj in gene_list:
@@ -1058,8 +1085,10 @@ def variant_export_genes_info(store, gene_list, genome_build="37"):
 
         canonical_txs += gene_canonical_txs
         primary_txs += gene_primary_txs
+        funct_anno = gene_obj.get("functional_annotation", "-")
+        funct_annos.append(funct_anno.replace("_", " "))
 
-    for item in [gene_ids, gene_names, canonical_txs, primary_txs]:
+    for item in [gene_ids, gene_names, canonical_txs, primary_txs, funct_annos]:
         gene_info.append(" | ".join(str(x) for x in item))
 
     return gene_info
@@ -1074,14 +1103,17 @@ def variants_export_header(case_obj):
                 + AD_reference, AD_alternate, GT_quality for each sample analysed for a case
     """
     header = []
-    header = header + EXPORT_HEADER
-    # Add fields specific for case samples
-    for individual in case_obj["individuals"]:
-        display_name = str(individual["display_name"])
-        header.append("GT_" + display_name)  # Add Genotype filed for a sample
-        header.append("AD_reference_" + display_name)  # Add AD reference field for a sample
-        header.append("AD_alternate_" + display_name)  # Add AD alternate field for a sample
-        header.append("GT_quality_" + display_name)  # Add Genotype quality field for a sample
+    if case_obj.get("track") == "cancer":
+        header = header + CANCER_EXPORT_HEADER
+    else:
+        header = header + EXPORT_HEADER
+        # Add fields specific for case samples
+        for individual in case_obj["individuals"]:
+            display_name = str(individual["display_name"])
+            header.append("GT_" + display_name)  # Add Genotype filed for a sample
+            header.append("AD_reference_" + display_name)  # Add AD reference field for a sample
+            header.append("AD_alternate_" + display_name)  # Add AD alternate field for a sample
+            header.append("GT_quality_" + display_name)  # Add Genotype quality field for a sample
     return header
 
 
@@ -1437,7 +1469,7 @@ def populate_sv_filters_form(store, institute_obj, case_obj, category, request_o
         form.variant_type.data = variant_type
         # set chromosome to all chromosomes
         form.chrom.data = request_obj.args.get("chrom", "")
-        if variant_type == "clinical":
+        if form.gene_panels.data == [] and variant_type == "clinical":
             form.gene_panels.data = case_default_panels(case_obj)
 
     else:  # POST
@@ -1445,6 +1477,8 @@ def populate_sv_filters_form(store, institute_obj, case_obj, category, request_o
             store, institute_obj, case_obj, user_obj, category, request_obj.form
         )
 
+    populate_force_show_unaffected_vars(institute_obj, form)
+
     # populate available panel choices
     form.gene_panels.choices = gene_panel_choices(store, institute_obj, case_obj)
 
@@ -1585,7 +1619,13 @@ def update_form_hgnc_symbols(store, case_obj, form):
 
     hgnc_symbols = []
     not_found_ids = []
-    genome_build = "38" if case_obj and "38" in str(case_obj.get("genome_build", "37")) else "37"
+    genome_build = None
+    case_obj = case_obj or {}
+
+    for build in ["37", "38"]:
+        if build in str(case_obj.get("genome_build", "")):
+            genome_build = build
+            break
 
     # retrieve current symbols from form
     if form.hgnc_symbols.data:
@@ -1595,15 +1635,16 @@ def update_form_hgnc_symbols(store, case_obj, form):
                 hgnc_gene_caption = store.hgnc_gene_caption(int(hgnc_symbol), genome_build)
                 if hgnc_gene_caption is None:
                     not_found_ids.append(hgnc_symbol)
-                else:
-                    hgnc_symbols.append(hgnc_gene_caption.get("hgnc_symbol", hgnc_symbol))
-            else:
-                hgnc_symbols.append(hgnc_symbol)
+                    continue
+                hgnc_symbols.append(hgnc_gene_caption.get("hgnc_symbol", hgnc_symbol))
+                continue
+
+            hgnc_symbols.append(hgnc_symbol)
 
     # add HPO genes to list, if they were missing
     if "hpo" in form.data.get("gene_panels", []):
         hpo_symbols = list(
-            set(term_obj["hgnc_symbol"] for term_obj in case_obj["dynamic_gene_list"])
+            set(term_obj["hgnc_symbol"] for term_obj in case_obj.get("dynamic_gene_list", []))
         )
 
         current_symbols = set(hgnc_symbols)
@@ -1621,53 +1662,6 @@ def update_form_hgnc_symbols(store, case_obj, form):
     return form
 
 
-def verified_excel_file(store, institute_list, temp_excel_dir):
-    """Collect all verified variants in a list on institutes and save them to file
-    Args:
-        store(adapter.MongoAdapter)
-        institute_list(list): a list of institute ids
-        temp_excel_dir(os.Path): folder where the temp excel files are written to
-    Returns:
-        written_files(int): the number of files written to temp_excel_dir
-    """
-    document_lines = []
-    written_files = 0
-    today = datetime.datetime.now().strftime("%Y-%m-%d")
-    LOG.info("Creating verified variant document..")
-
-    for cust in institute_list:
-        verif_vars = store.verified(institute_id=cust)
-        LOG.info("Found {} verified variants for customer {}".format(len(verif_vars), cust))
-
-        if not verif_vars:
-            continue
-        unique_callers = set()
-        for var_type, var_callers in CALLERS.items():
-            for caller in var_callers:
-                unique_callers.add(caller.get("id"))
-        cust_verified = export_verified_variants(verif_vars, unique_callers)
-
-        document_name = ".".join([cust, "_verified_variants", today]) + ".xlsx"
-        workbook = Workbook(os.path.join(temp_excel_dir, document_name))
-        Report_Sheet = workbook.add_worksheet()
-
-        # Write the column header
-        row = 0
-        for col, field in enumerate(VERIFIED_VARIANTS_HEADER + list(unique_callers)):
-            Report_Sheet.write(row, col, field)
-
-        # Write variant lines, after header (start at line 1)
-        for row, line in enumerate(cust_verified, 1):  # each line becomes a row in the document
-            for col, field in enumerate(line):  # each field in line becomes a cell
-                Report_Sheet.write(row, col, field)
-        workbook.close()
-
-        if os.path.exists(os.path.join(temp_excel_dir, document_name)):
-            written_files += 1
-
-    return written_files
-
-
 def activate_case(store, institute_obj, case_obj, current_user):
     """Activate case when visited for the first time.
 
