@@ -1,17 +1,61 @@
 # -*- coding: utf-8 -*-
 import datetime
+import tempfile
 
+import pytest
 import requests
 from bson.objectid import ObjectId
 from flask import current_app, json, url_for
 
-from scout.demo import delivery_report_path
+from scout.constants import CUSTOM_CASE_REPORTS
 from scout.server.blueprints.cases.views import parse_raw_gene_ids, parse_raw_gene_symbols
 from scout.server.extensions import store
 
 TEST_TOKEN = "test_token"
 
 
+@pytest.mark.parametrize("report_types", list(CUSTOM_CASE_REPORTS.keys()))
+def test_custom_report(app, institute_obj, case_obj, report_types):
+    """Test the function that serves custom report data with all types of report in CUSTOM_CASE_REPORTS"""
+
+    with tempfile.NamedTemporaryFile(suffix=".html") as tf:
+        # GIVEN that the case contains the given report (for convenience load also cancer case report types in RD demo case)
+        case_obj[report_types] = tf.name
+        store.replace_case(case_obj)
+
+        # GIVEN an initialized app and a valid user and institute
+        with app.test_client() as client:
+            # GIVEN that the user could be logged in
+            client.get(url_for("auto_login"))
+
+            # WHEN displaying an HTML report:
+            resp = client.get(
+                url_for(
+                    "cases.custom_report",
+                    institute_id=institute_obj["internal_id"],
+                    case_name=case_obj["display_name"],
+                    report_type=report_types,
+                )
+            )
+            # THEN a successful response should be returned
+            assert resp.status_code == 200
+            assert resp.mimetype == "text/html"
+
+            # WHEN displaying a PDF report:
+            resp = client.get(
+                url_for(
+                    "cases.custom_report",
+                    institute_id=institute_obj["internal_id"],
+                    case_name=case_obj["display_name"],
+                    report_type=report_types,
+                    report_format="pdf",
+                )
+            )
+            # THEN a successful response should be returned
+            assert resp.status_code == 200
+            assert resp.mimetype == "application/pdf"
+
+
 def test_add_individual_phenotype(app, institute_obj):
     """Test adding a phenotype term (HPO) for a case"""
 
@@ -713,29 +757,6 @@ def test_pdf_case_report(app, institute_obj, case_obj):
         assert resp.status_code == 200
 
 
-def test_gene_fusion_report(app, institute_obj, case_obj):
-    """Test the endpoint that allows users to download the PDF file containing the gene fusion report."""
-    # GIVEN an initialized app and a valid user and institute
-    with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
-
-        # When clicking on gene fusion report link button on the sidebar
-        resp = client.get(
-            url_for(
-                "cases.gene_fusion_report",
-                institute_id=institute_obj["internal_id"],
-                case_name=case_obj["display_name"],
-                report_type="gene_fusion_report",
-            )
-        )
-        # a successful response should be returned
-        assert resp.status_code == 200
-        # And the downloaded file should be a PDF file
-        assert resp.mimetype == "application/pdf"
-
-
 def test_mt_report(app, institute_obj, case_obj):
     # GIVEN an initialized app
     # GIVEN a valid user and institute
@@ -788,82 +809,6 @@ def test_status(app, institute_obj, case_obj, user_obj, mocker, mock_redirect):
         assert resp.status_code == 302  # page should be redirected
 
 
-def _test_delivery_report(client, institute_obj, case_obj, response_format):
-    """Test helper: test report of given format"""
-
-    # WHEN the case has a delivery report
-    store.case_collection.update_one(
-        {"_id": case_obj["_id"]},
-        {"$set": {"delivery_report": delivery_report_path}},
-    )
-
-    # WHEN accessing the delivery report page with the format=pdf param
-    resp = client.get(
-        url_for(
-            "cases.delivery_report",
-            institute_id=institute_obj["internal_id"],
-            case_name=case_obj["display_name"],
-            format=response_format,
-        )
-    )
-    return resp
-
-
-def test_html_delivery_report(app, institute_obj, case_obj, user_obj):
-
-    # GIVEN an initialized app
-    # GIVEN a valid user and institute
-    with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
-
-        resp = _test_delivery_report(client, institute_obj, case_obj, response_format="html")
-        # THEN the endpoint should return the delivery report HTML page
-        assert "Leveransrapport Clinical Genomics" in str(resp.data)
-
-
-def test_pdf_delivery_report(app, institute_obj, case_obj, user_obj):
-
-    # GIVEN an initialized app
-    # GIVEN a valid user and institute
-    with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
-
-        resp = _test_delivery_report(client, institute_obj, case_obj, response_format="pdf")
-        # a successful response should be returned
-        assert resp.status_code == 200
-        # and it should contain a pdf file, not HTML code
-        assert resp.mimetype == "application/pdf"
-
-
-def test_pdf_coverage_qc_report(app, institute_obj, cancer_case_obj, user_obj):
-    """Test the endpoint that returns a cancer case's coverage and qc report in PDF format"""
-
-    # GIVEN a database containing a cancer case
-    store.case_collection.insert_one(cancer_case_obj)
-
-    # GIVEN an initialized app
-    with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        # WHEN accessing the coverage and qc report with the format=pdf param
-        resp = client.get(
-            url_for(
-                "cases.coverage_qc_report",
-                institute_id=institute_obj["internal_id"],
-                case_name=cancer_case_obj["display_name"],
-                format="pdf",
-            )
-        )
-        # a successful response should be returned
-        assert resp.status_code == 200
-        # and it should contain a PDF file
-        assert resp.mimetype == "application/pdf"
-
-
 def test_caselist(app, case_obj):
     """Test the API return of cases for autocompletion"""
 
