@@ -156,6 +156,24 @@ def test_panel_export(client, real_panel_database):
     assert resp.status_code == 200
 
 
+def test_panel_export_case_hits(client, real_panel_database):
+    """Test function used for exporting all genes with variant hits for a case"""
+
+    # GIVEN a case and a gene panel in the database
+    adapter = real_panel_database
+    panel_obj = adapter.panel_collection.find_one()
+    case_obj = adapter.case_collection.find_one()
+
+    # WHEN downloading the case variants hits report
+    form_data = {"case_name": " - ".join([case_obj["owner"], case_obj["display_name"]])}
+    resp = client.post(url_for("panels.panel_export", panel_id=panel_obj["_id"]), data=form_data)
+
+    # THEN the response should be successful
+    assert resp.status_code == 200
+    # And should download a PDF file
+    assert resp.mimetype == "application/pdf"
+
+
 def test_gene_edit(client, real_panel_database):
     """Test interface that allows gene panel editing, GET method"""
     adapter = real_panel_database
